package com.me.brickbuster.entity;

import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.glutils.ShapeRenderer;
import com.badlogic.gdx.graphics.glutils.ShapeRenderer.ShapeType;
import com.badlogic.gdx.math.Vector2;
import com.me.brickbuster.entity.powerup.PowerUpType;
import com.me.brickbuster.state.PlayState;

public class Brick extends Entity {

	public static final Color DEFAULT_COLOR = Color.FOREST;
	public static final int BRICK_WIDTH = 200;
	public static final int BRICK_HEIGHT = 100;

	private PowerUpType powerUpType;
	private Color color;

	private Vector2[] vertices;

	public Brick(PlayState state, PowerUpType powerUpType, int x, int y) {
		this(state, powerUpType, true, x, y);
	}

	public Brick(PlayState state, PowerUpType powerUpType, boolean hidePowerup, int x, int y) {
		this(state, powerUpType, DEFAULT_COLOR, hidePowerup, x, y);
	}

	public Brick(PlayState state, PowerUpType powerUpType, Color color, boolean hidePowerUp, int x, int y) {
		super(state, x, y);
		this.powerUpType = powerUpType;
		this.color = powerUpType != null && !hidePowerUp? powerUpType.getColor() : color;
		this.vertices = new Vector2[] {
			new Vector2(x, y),
			new Vector2(x + BRICK_WIDTH, y),
			new Vector2(x + BRICK_WIDTH, y + BRICK_HEIGHT),
			new Vector2(x, y + BRICK_HEIGHT)
		};
	}

	@Override
	public void render(ShapeRenderer sr) {
		sr.begin(ShapeType.Filled);
		sr.setColor(color);
		sr.rect(getX(), getY(), BRICK_WIDTH, BRICK_HEIGHT);
		sr.end();
	}

	@Override
	public void update(float dt) {
	}

	public boolean hit() {
		if (state.bricks.size()-1 <= Ball.BLOCKS_FOR_BOOST) {
			for (Ball ball : state.balls) {
				ball.setSpeed(Ball.BOOST_SPEED);
			}
		}

		if (powerUpType != null) {
			state.powerUps.add(powerUpType.createInstance(state, this));
		}
		return true;
	}

	public Vector2[] getVertices() {
		return vertices;
	}

}
